Description Usage Arguments Value Examples
Inpsired by locate() from numerical recipes,
findInterval and
VALUE_LOCATE() from IDL.
1 |
x |
vector of values (in any order) including sortable character types |
vec |
ordered vector (ascending or descending) of same type as |
... |
other arguments for |
vector of indices ranging from 0 to the length of vec
0 indices indicate x values less than the left most value of vec
For ascending vectors, the index, i, of x is found where vex[i] <= x < vec[i+1] with an open right-hand end
For descending vectors, the index, i, of x is found where vex[i] >= x > vec[i+1] with an open right-hand end
1 2 3 4 5 6 7 8 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.